/*
 * Copyright 2015 Intel Corporation
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice (including the next
 *  paragraph) shall be included in all copies or substantial portions of the
 *  Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

#include "isl.h"

const struct isl_format_layout
isl_format_layouts[] = {
   [ISL_FORMAT_R32G32B32A32_FLOAT] = {
      ISL_FORMAT_R32G32B32A32_FLOAT,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 32 },
          .g = { ISL_SFLOAT, 32 },
          .b = { ISL_SFLOAT, 32 },
          .a = { ISL_SFLOAT, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32A32_SINT] = {
      ISL_FORMAT_R32G32B32A32_SINT,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 32 },
          .g = { ISL_SINT, 32 },
          .b = { ISL_SINT, 32 },
          .a = { ISL_SINT, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32A32_UINT] = {
      ISL_FORMAT_R32G32B32A32_UINT,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 32 },
          .g = { ISL_UINT, 32 },
          .b = { ISL_UINT, 32 },
          .a = { ISL_UINT, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32A32_UNORM] = {
      ISL_FORMAT_R32G32B32A32_UNORM,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 32 },
          .g = { ISL_UNORM, 32 },
          .b = { ISL_UNORM, 32 },
          .a = { ISL_UNORM, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32A32_SNORM] = {
      ISL_FORMAT_R32G32B32A32_SNORM,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 32 },
          .g = { ISL_SNORM, 32 },
          .b = { ISL_SNORM, 32 },
          .a = { ISL_SNORM, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R64G64_FLOAT] = {
      ISL_FORMAT_R64G64_FLOAT,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 64 },
          .g = { ISL_SFLOAT, 64 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32X32_FLOAT] = {
      ISL_FORMAT_R32G32B32X32_FLOAT,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 32 },
          .g = { ISL_SFLOAT, 32 },
          .b = { ISL_SFLOAT, 32 },
          .a = { ISL_VOID, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32A32_SSCALED] = {
      ISL_FORMAT_R32G32B32A32_SSCALED,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 32 },
          .g = { ISL_SSCALED, 32 },
          .b = { ISL_SSCALED, 32 },
          .a = { ISL_SSCALED, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32A32_USCALED] = {
      ISL_FORMAT_R32G32B32A32_USCALED,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 32 },
          .g = { ISL_USCALED, 32 },
          .b = { ISL_USCALED, 32 },
          .a = { ISL_USCALED, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32A32_SFIXED] = {
      ISL_FORMAT_R32G32B32A32_SFIXED,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFIXED, 32 },
          .g = { ISL_SFIXED, 32 },
          .b = { ISL_SFIXED, 32 },
          .a = { ISL_SFIXED, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R64G64_PASSTHRU] = {
      ISL_FORMAT_R64G64_PASSTHRU,
      .bs = 16,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_RAW, 64 },
          .g = { ISL_RAW, 64 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32_FLOAT] = {
      ISL_FORMAT_R32G32B32_FLOAT,
      .bs = 12,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 32 },
          .g = { ISL_SFLOAT, 32 },
          .b = { ISL_SFLOAT, 32 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32_SINT] = {
      ISL_FORMAT_R32G32B32_SINT,
      .bs = 12,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 32 },
          .g = { ISL_SINT, 32 },
          .b = { ISL_SINT, 32 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32_UINT] = {
      ISL_FORMAT_R32G32B32_UINT,
      .bs = 12,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 32 },
          .g = { ISL_UINT, 32 },
          .b = { ISL_UINT, 32 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32_UNORM] = {
      ISL_FORMAT_R32G32B32_UNORM,
      .bs = 12,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 32 },
          .g = { ISL_UNORM, 32 },
          .b = { ISL_UNORM, 32 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32_SNORM] = {
      ISL_FORMAT_R32G32B32_SNORM,
      .bs = 12,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 32 },
          .g = { ISL_SNORM, 32 },
          .b = { ISL_SNORM, 32 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32_SSCALED] = {
      ISL_FORMAT_R32G32B32_SSCALED,
      .bs = 12,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 32 },
          .g = { ISL_SSCALED, 32 },
          .b = { ISL_SSCALED, 32 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32_USCALED] = {
      ISL_FORMAT_R32G32B32_USCALED,
      .bs = 12,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 32 },
          .g = { ISL_USCALED, 32 },
          .b = { ISL_USCALED, 32 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32B32_SFIXED] = {
      ISL_FORMAT_R32G32B32_SFIXED,
      .bs = 12,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFIXED, 32 },
          .g = { ISL_SFIXED, 32 },
          .b = { ISL_SFIXED, 32 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16A16_UNORM] = {
      ISL_FORMAT_R16G16B16A16_UNORM,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 16 },
          .g = { ISL_UNORM, 16 },
          .b = { ISL_UNORM, 16 },
          .a = { ISL_UNORM, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16A16_SNORM] = {
      ISL_FORMAT_R16G16B16A16_SNORM,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 16 },
          .g = { ISL_SNORM, 16 },
          .b = { ISL_SNORM, 16 },
          .a = { ISL_SNORM, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16A16_SINT] = {
      ISL_FORMAT_R16G16B16A16_SINT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 16 },
          .g = { ISL_SINT, 16 },
          .b = { ISL_SINT, 16 },
          .a = { ISL_SINT, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16A16_UINT] = {
      ISL_FORMAT_R16G16B16A16_UINT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 16 },
          .g = { ISL_UINT, 16 },
          .b = { ISL_UINT, 16 },
          .a = { ISL_UINT, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16A16_FLOAT] = {
      ISL_FORMAT_R16G16B16A16_FLOAT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 16 },
          .g = { ISL_SFLOAT, 16 },
          .b = { ISL_SFLOAT, 16 },
          .a = { ISL_SFLOAT, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32_FLOAT] = {
      ISL_FORMAT_R32G32_FLOAT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 32 },
          .g = { ISL_SFLOAT, 32 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32_SINT] = {
      ISL_FORMAT_R32G32_SINT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 32 },
          .g = { ISL_SINT, 32 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32_UINT] = {
      ISL_FORMAT_R32G32_UINT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 32 },
          .g = { ISL_UINT, 32 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_FLOAT_X8X24_TYPELESS] = {
      ISL_FORMAT_R32_FLOAT_X8X24_TYPELESS,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 32 },
          .g = { ISL_VOID, 8 },
          .b = { ISL_VOID, 24 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_X32_TYPELESS_G8X24_UINT] = {
      ISL_FORMAT_X32_TYPELESS_G8X24_UINT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_VOID, 32 },
          .g = { ISL_UINT, 8 },
          .b = { ISL_VOID, 24 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L32A32_FLOAT] = {
      ISL_FORMAT_L32A32_FLOAT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_SFLOAT, 32 },
          .l = { ISL_SFLOAT, 32 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32_UNORM] = {
      ISL_FORMAT_R32G32_UNORM,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 32 },
          .g = { ISL_UNORM, 32 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32_SNORM] = {
      ISL_FORMAT_R32G32_SNORM,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 32 },
          .g = { ISL_SNORM, 32 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R64_FLOAT] = {
      ISL_FORMAT_R64_FLOAT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 64 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16X16_UNORM] = {
      ISL_FORMAT_R16G16B16X16_UNORM,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 16 },
          .g = { ISL_UNORM, 16 },
          .b = { ISL_UNORM, 16 },
          .a = { ISL_VOID, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16X16_FLOAT] = {
      ISL_FORMAT_R16G16B16X16_FLOAT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 16 },
          .g = { ISL_SFLOAT, 16 },
          .b = { ISL_SFLOAT, 16 },
          .a = { ISL_VOID, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A32X32_FLOAT] = {
      ISL_FORMAT_A32X32_FLOAT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_SFLOAT, 32 },
          .l = { ISL_VOID, 32 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L32X32_FLOAT] = {
      ISL_FORMAT_L32X32_FLOAT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_VOID, 32 },
          .l = { ISL_SFLOAT, 32 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_I32X32_FLOAT] = {
      ISL_FORMAT_I32X32_FLOAT,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_VOID, 32 },
          .l = {},
          .i = { ISL_SFLOAT, 32 },
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16A16_SSCALED] = {
      ISL_FORMAT_R16G16B16A16_SSCALED,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 16 },
          .g = { ISL_SSCALED, 16 },
          .b = { ISL_SSCALED, 16 },
          .a = { ISL_SSCALED, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16A16_USCALED] = {
      ISL_FORMAT_R16G16B16A16_USCALED,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 16 },
          .g = { ISL_USCALED, 16 },
          .b = { ISL_USCALED, 16 },
          .a = { ISL_USCALED, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32_SSCALED] = {
      ISL_FORMAT_R32G32_SSCALED,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 32 },
          .g = { ISL_SSCALED, 32 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32_USCALED] = {
      ISL_FORMAT_R32G32_USCALED,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 32 },
          .g = { ISL_USCALED, 32 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32G32_SFIXED] = {
      ISL_FORMAT_R32G32_SFIXED,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFIXED, 32 },
          .g = { ISL_SFIXED, 32 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R64_PASSTHRU] = {
      ISL_FORMAT_R64_PASSTHRU,
      .bs = 8,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_RAW, 64 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B8G8R8A8_UNORM] = {
      ISL_FORMAT_B8G8R8A8_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B8G8R8A8_UNORM_SRGB] = {
      ISL_FORMAT_B8G8R8A8_UNORM_SRGB,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10A2_UNORM] = {
      ISL_FORMAT_R10G10B10A2_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 10 },
          .g = { ISL_UNORM, 10 },
          .b = { ISL_UNORM, 10 },
          .a = { ISL_UNORM, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10A2_UNORM_SRGB] = {
      ISL_FORMAT_R10G10B10A2_UNORM_SRGB,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 10 },
          .g = { ISL_UNORM, 10 },
          .b = { ISL_UNORM, 10 },
          .a = { ISL_UNORM, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10A2_UINT] = {
      ISL_FORMAT_R10G10B10A2_UINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 10 },
          .g = { ISL_UINT, 10 },
          .b = { ISL_UINT, 10 },
          .a = { ISL_UINT, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10_SNORM_A2_UNORM] = {
      ISL_FORMAT_R10G10B10_SNORM_A2_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 10 },
          .g = { ISL_SNORM, 10 },
          .b = { ISL_SNORM, 10 },
          .a = { ISL_UNORM, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8A8_UNORM] = {
      ISL_FORMAT_R8G8B8A8_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8A8_UNORM_SRGB] = {
      ISL_FORMAT_R8G8B8A8_UNORM_SRGB,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8A8_SNORM] = {
      ISL_FORMAT_R8G8B8A8_SNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = { ISL_SNORM, 8 },
          .b = { ISL_SNORM, 8 },
          .a = { ISL_SNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8A8_SINT] = {
      ISL_FORMAT_R8G8B8A8_SINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 8 },
          .g = { ISL_SINT, 8 },
          .b = { ISL_SINT, 8 },
          .a = { ISL_SINT, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8A8_UINT] = {
      ISL_FORMAT_R8G8B8A8_UINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 8 },
          .g = { ISL_UINT, 8 },
          .b = { ISL_UINT, 8 },
          .a = { ISL_UINT, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16_UNORM] = {
      ISL_FORMAT_R16G16_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 16 },
          .g = { ISL_UNORM, 16 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16_SNORM] = {
      ISL_FORMAT_R16G16_SNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 16 },
          .g = { ISL_SNORM, 16 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16_SINT] = {
      ISL_FORMAT_R16G16_SINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 16 },
          .g = { ISL_SINT, 16 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16_UINT] = {
      ISL_FORMAT_R16G16_UINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 16 },
          .g = { ISL_UINT, 16 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16_FLOAT] = {
      ISL_FORMAT_R16G16_FLOAT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 16 },
          .g = { ISL_SFLOAT, 16 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B10G10R10A2_UNORM] = {
      ISL_FORMAT_B10G10R10A2_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 10 },
          .g = { ISL_UNORM, 10 },
          .b = { ISL_UNORM, 10 },
          .a = { ISL_UNORM, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B10G10R10A2_UNORM_SRGB] = {
      ISL_FORMAT_B10G10R10A2_UNORM_SRGB,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 10 },
          .g = { ISL_UNORM, 10 },
          .b = { ISL_UNORM, 10 },
          .a = { ISL_UNORM, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R11G11B10_FLOAT] = {
      ISL_FORMAT_R11G11B10_FLOAT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UFLOAT, 11 },
          .g = { ISL_UFLOAT, 11 },
          .b = { ISL_UFLOAT, 10 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_SINT] = {
      ISL_FORMAT_R32_SINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 32 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_UINT] = {
      ISL_FORMAT_R32_UINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 32 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_FLOAT] = {
      ISL_FORMAT_R32_FLOAT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 32 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R24_UNORM_X8_TYPELESS] = {
      ISL_FORMAT_R24_UNORM_X8_TYPELESS,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 24 },
          .g = { ISL_VOID, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_X24_TYPELESS_G8_UINT] = {
      ISL_FORMAT_X24_TYPELESS_G8_UINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_VOID, 24 },
          .g = { ISL_UINT, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L32_UNORM] = {
      ISL_FORMAT_L32_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = { ISL_UNORM, 32 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A32_UNORM] = {
      ISL_FORMAT_A32_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L16A16_UNORM] = {
      ISL_FORMAT_L16A16_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 16 },
          .l = { ISL_UNORM, 16 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_I24X8_UNORM] = {
      ISL_FORMAT_I24X8_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_VOID, 8 },
          .l = {},
          .i = { ISL_UNORM, 24 },
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L24X8_UNORM] = {
      ISL_FORMAT_L24X8_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_VOID, 8 },
          .l = { ISL_UNORM, 24 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A24X8_UNORM] = {
      ISL_FORMAT_A24X8_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 24 },
          .l = { ISL_VOID, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_I32_FLOAT] = {
      ISL_FORMAT_I32_FLOAT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = { ISL_SFLOAT, 32 },
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L32_FLOAT] = {
      ISL_FORMAT_L32_FLOAT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = { ISL_SFLOAT, 32 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A32_FLOAT] = {
      ISL_FORMAT_A32_FLOAT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_SFLOAT, 32 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_X8B8_UNORM_G8R8_SNORM] = {
      ISL_FORMAT_X8B8_UNORM_G8R8_SNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = { ISL_SNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_VOID, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A8X8_UNORM_G8R8_SNORM] = {
      ISL_FORMAT_A8X8_UNORM_G8R8_SNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = { ISL_SNORM, 8 },
          .b = { ISL_VOID, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B8X8_UNORM_G8R8_SNORM] = {
      ISL_FORMAT_B8X8_UNORM_G8R8_SNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = { ISL_SNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_VOID, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B8G8R8X8_UNORM] = {
      ISL_FORMAT_B8G8R8X8_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_VOID, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B8G8R8X8_UNORM_SRGB] = {
      ISL_FORMAT_B8G8R8X8_UNORM_SRGB,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_VOID, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8X8_UNORM] = {
      ISL_FORMAT_R8G8B8X8_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_VOID, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8X8_UNORM_SRGB] = {
      ISL_FORMAT_R8G8B8X8_UNORM_SRGB,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_VOID, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R9G9B9E5_SHAREDEXP] = {
      ISL_FORMAT_R9G9B9E5_SHAREDEXP,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 9 },
          .g = { ISL_UINT, 9 },
          .b = { ISL_UINT, 9 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B10G10R10X2_UNORM] = {
      ISL_FORMAT_B10G10R10X2_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 10 },
          .g = { ISL_UNORM, 10 },
          .b = { ISL_UNORM, 10 },
          .a = { ISL_VOID, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L16A16_FLOAT] = {
      ISL_FORMAT_L16A16_FLOAT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_SFLOAT, 16 },
          .l = { ISL_SFLOAT, 16 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_UNORM] = {
      ISL_FORMAT_R32_UNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 32 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_SNORM] = {
      ISL_FORMAT_R32_SNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 32 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10X2_USCALED] = {
      ISL_FORMAT_R10G10B10X2_USCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 10 },
          .g = { ISL_USCALED, 10 },
          .b = { ISL_USCALED, 10 },
          .a = { ISL_VOID, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8A8_SSCALED] = {
      ISL_FORMAT_R8G8B8A8_SSCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 8 },
          .g = { ISL_SSCALED, 8 },
          .b = { ISL_SSCALED, 8 },
          .a = { ISL_SSCALED, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8A8_USCALED] = {
      ISL_FORMAT_R8G8B8A8_USCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 8 },
          .g = { ISL_USCALED, 8 },
          .b = { ISL_USCALED, 8 },
          .a = { ISL_USCALED, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16_SSCALED] = {
      ISL_FORMAT_R16G16_SSCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 16 },
          .g = { ISL_SSCALED, 6 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16_USCALED] = {
      ISL_FORMAT_R16G16_USCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 16 },
          .g = { ISL_USCALED, 16 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_SSCALED] = {
      ISL_FORMAT_R32_SSCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 32 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_USCALED] = {
      ISL_FORMAT_R32_USCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 32 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B5G6R5_UNORM] = {
      ISL_FORMAT_B5G6R5_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 5 },
          .g = { ISL_UNORM, 6 },
          .b = { ISL_UNORM, 5 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B5G6R5_UNORM_SRGB] = {
      ISL_FORMAT_B5G6R5_UNORM_SRGB,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 5 },
          .g = { ISL_UNORM, 6 },
          .b = { ISL_UNORM, 5 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B5G5R5A1_UNORM] = {
      ISL_FORMAT_B5G5R5A1_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 5 },
          .g = { ISL_UNORM, 5 },
          .b = { ISL_UNORM, 5 },
          .a = { ISL_UNORM, 1 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B5G5R5A1_UNORM_SRGB] = {
      ISL_FORMAT_B5G5R5A1_UNORM_SRGB,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 5 },
          .g = { ISL_UNORM, 5 },
          .b = { ISL_UNORM, 5 },
          .a = { ISL_UNORM, 1 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B4G4R4A4_UNORM] = {
      ISL_FORMAT_B4G4R4A4_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B4G4R4A4_UNORM_SRGB] = {
      ISL_FORMAT_B4G4R4A4_UNORM_SRGB,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8_UNORM] = {
      ISL_FORMAT_R8G8_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8_SNORM] = {
      ISL_FORMAT_R8G8_SNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = { ISL_SNORM, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8_SINT] = {
      ISL_FORMAT_R8G8_SINT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 8 },
          .g = { ISL_SINT, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8_UINT] = {
      ISL_FORMAT_R8G8_UINT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 8 },
          .g = { ISL_UINT, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16_UNORM] = {
      ISL_FORMAT_R16_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 16 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16_SNORM] = {
      ISL_FORMAT_R16_SNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 16 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16_SINT] = {
      ISL_FORMAT_R16_SINT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 16 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16_UINT] = {
      ISL_FORMAT_R16_UINT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 16 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16_FLOAT] = {
      ISL_FORMAT_R16_FLOAT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 16 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A8P8_UNORM_PALETTE0] = {
      ISL_FORMAT_A8P8_UNORM_PALETTE0,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 8 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A8P8_UNORM_PALETTE1] = {
      ISL_FORMAT_A8P8_UNORM_PALETTE1,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 8 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_I16_UNORM] = {
      ISL_FORMAT_I16_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = { ISL_UNORM, 16 },
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L16_UNORM] = {
      ISL_FORMAT_L16_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = { ISL_UNORM, 16 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A16_UNORM] = {
      ISL_FORMAT_A16_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L8A8_UNORM] = {
      ISL_FORMAT_L8A8_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 8 },
          .l = { ISL_UNORM, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_I16_FLOAT] = {
      ISL_FORMAT_I16_FLOAT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = { ISL_SFLOAT, 16 },
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L16_FLOAT] = {
      ISL_FORMAT_L16_FLOAT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = { ISL_SFLOAT, 16 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A16_FLOAT] = {
      ISL_FORMAT_A16_FLOAT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_SFLOAT, 16 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L8A8_UNORM_SRGB] = {
      ISL_FORMAT_L8A8_UNORM_SRGB,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 8 },
          .l = { ISL_UNORM, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R5G5_SNORM_B6_UNORM] = {
      ISL_FORMAT_R5G5_SNORM_B6_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 5 },
          .g = { ISL_SNORM, 5 },
          .b = { ISL_UNORM, 6 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B5G5R5X1_UNORM] = {
      ISL_FORMAT_B5G5R5X1_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 5 },
          .g = { ISL_UNORM, 5 },
          .b = { ISL_UNORM, 5 },
          .a = { ISL_VOID, 1 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B5G5R5X1_UNORM_SRGB] = {
      ISL_FORMAT_B5G5R5X1_UNORM_SRGB,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 5 },
          .g = { ISL_UNORM, 5 },
          .b = { ISL_UNORM, 5 },
          .a = { ISL_VOID, 1 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8_SSCALED] = {
      ISL_FORMAT_R8G8_SSCALED,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 8 },
          .g = { ISL_SSCALED, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8_USCALED] = {
      ISL_FORMAT_R8G8_USCALED,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 8 },
          .g = { ISL_USCALED, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16_SSCALED] = {
      ISL_FORMAT_R16_SSCALED,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 16 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16_USCALED] = {
      ISL_FORMAT_R16_USCALED,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 16 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_P8A8_UNORM_PALETTE0] = {
      ISL_FORMAT_P8A8_UNORM_PALETTE0,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 8 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_P8A8_UNORM_PALETTE1] = {
      ISL_FORMAT_P8A8_UNORM_PALETTE1,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 8 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A1B5G5R5_UNORM] = {
      ISL_FORMAT_A1B5G5R5_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 5 },
          .g = { ISL_UNORM, 5 },
          .b = { ISL_UNORM, 5 },
          .a = { ISL_UNORM, 1 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A4B4G4R4_UNORM] = {
      ISL_FORMAT_A4B4G4R4_UNORM,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L8A8_UINT] = {
      ISL_FORMAT_L8A8_UINT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UINT, 8 },
          .l = { ISL_UINT, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L8A8_SINT] = {
      ISL_FORMAT_L8A8_SINT,
      .bs = 2,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_SINT, 8 },
          .l = { ISL_SINT, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8_UNORM] = {
      ISL_FORMAT_R8_UNORM,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8_SNORM] = {
      ISL_FORMAT_R8_SNORM,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8_SINT] = {
      ISL_FORMAT_R8_SINT,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 8 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8_UINT] = {
      ISL_FORMAT_R8_UINT,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 8 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A8_UNORM] = {
      ISL_FORMAT_A8_UNORM,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_I8_UNORM] = {
      ISL_FORMAT_I8_UNORM,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = { ISL_UNORM, 8 },
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L8_UNORM] = {
      ISL_FORMAT_L8_UNORM,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = { ISL_UNORM, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_P4A4_UNORM_PALETTE0] = {
      ISL_FORMAT_P4A4_UNORM_PALETTE0,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 4 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A4P4_UNORM_PALETTE0] = {
      ISL_FORMAT_A4P4_UNORM_PALETTE0,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 4 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8_SSCALED] = {
      ISL_FORMAT_R8_SSCALED,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 8 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8_USCALED] = {
      ISL_FORMAT_R8_USCALED,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 8 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_P8_UNORM_PALETTE0] = {
      ISL_FORMAT_P8_UNORM_PALETTE0,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 8 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L8_UNORM_SRGB] = {
      ISL_FORMAT_L8_UNORM_SRGB,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = { ISL_UNORM, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_P8_UNORM_PALETTE1] = {
      ISL_FORMAT_P8_UNORM_PALETTE1,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 8 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_P4A4_UNORM_PALETTE1] = {
      ISL_FORMAT_P4A4_UNORM_PALETTE1,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 4 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_A4P4_UNORM_PALETTE1] = {
      ISL_FORMAT_A4P4_UNORM_PALETTE1,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 4 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_Y8_UNORM] = {
      ISL_FORMAT_Y8_UNORM,
      .bs = 0,
      .bw = 0, .bh = 0, .bd = 0,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_YUV,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L8_UINT] = {
      ISL_FORMAT_L8_UINT,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = { ISL_UINT, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_L8_SINT] = {
      ISL_FORMAT_L8_SINT,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = { ISL_SINT, 8 },
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_I8_UINT] = {
      ISL_FORMAT_I8_UINT,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = { ISL_UINT, 8 },
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_I8_SINT] = {
      ISL_FORMAT_I8_SINT,
      .bs = 1,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = { ISL_SINT, 8 },
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_DXT1_RGB_SRGB] = {
      ISL_FORMAT_DXT1_RGB_SRGB,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_DXT1,
   },

   [ISL_FORMAT_R1_UNORM] = {
      ISL_FORMAT_R1_UNORM,
      .bs = 0,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 1 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_YCRCB_NORMAL] = {
      ISL_FORMAT_YCRCB_NORMAL,
      .bs = 0,
      .bw = 0, .bh = 0, .bd = 0,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_YUV,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_YCRCB_SWAPUVY] = {
      ISL_FORMAT_YCRCB_SWAPUVY,
      .bs = 0,
      .bw = 0, .bh = 0, .bd = 0,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_YUV,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_P2_UNORM_PALETTE0] = {
      ISL_FORMAT_P2_UNORM_PALETTE0,
      .bs = 0,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 2 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_P2_UNORM_PALETTE1] = {
      ISL_FORMAT_P2_UNORM_PALETTE1,
      .bs = 0,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = { ISL_UNORM, 2 },
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_BC1_UNORM] = {
      ISL_FORMAT_BC1_UNORM,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_DXT1,
   },

   [ISL_FORMAT_BC2_UNORM] = {
      ISL_FORMAT_BC2_UNORM,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_DXT3,
   },

   [ISL_FORMAT_BC3_UNORM] = {
      ISL_FORMAT_BC3_UNORM,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_DXT5,
   },

   [ISL_FORMAT_BC4_UNORM] = {
      ISL_FORMAT_BC4_UNORM,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_RGTC1,
   },

   [ISL_FORMAT_BC5_UNORM] = {
      ISL_FORMAT_BC5_UNORM,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_RGTC2,
   },

   [ISL_FORMAT_BC1_UNORM_SRGB] = {
      ISL_FORMAT_BC1_UNORM_SRGB,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_DXT1,
   },

   [ISL_FORMAT_BC2_UNORM_SRGB] = {
      ISL_FORMAT_BC2_UNORM_SRGB,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_DXT3,
   },

   [ISL_FORMAT_BC3_UNORM_SRGB] = {
      ISL_FORMAT_BC3_UNORM_SRGB,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = { ISL_UNORM, 4 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_DXT5,
   },

   [ISL_FORMAT_MONO8] = {
      ISL_FORMAT_MONO8,
      .bs = 0,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_YCRCB_SWAPUV] = {
      ISL_FORMAT_YCRCB_SWAPUV,
      .bs = 0,
      .bw = 0, .bh = 0, .bd = 0,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_YUV,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_YCRCB_SWAPY] = {
      ISL_FORMAT_YCRCB_SWAPY,
      .bs = 0,
      .bw = 0, .bh = 0, .bd = 0,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_YUV,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_DXT1_RGB] = {
      ISL_FORMAT_DXT1_RGB,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_DXT1,
   },

   [ISL_FORMAT_FXT1] = {
      ISL_FORMAT_FXT1,
      .bs = 16,
      .bw = 8, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 4 },
          .g = { ISL_UNORM, 4 },
          .b = { ISL_UNORM, 4 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_FXT1,
   },

   [ISL_FORMAT_R8G8B8_UNORM] = {
      ISL_FORMAT_R8G8B8_UNORM,
      .bs = 3,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8_SNORM] = {
      ISL_FORMAT_R8G8B8_SNORM,
      .bs = 3,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = { ISL_SNORM, 8 },
          .b = { ISL_SNORM, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8_SSCALED] = {
      ISL_FORMAT_R8G8B8_SSCALED,
      .bs = 3,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 8 },
          .g = { ISL_SSCALED, 8 },
          .b = { ISL_SSCALED, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8_USCALED] = {
      ISL_FORMAT_R8G8B8_USCALED,
      .bs = 3,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 8 },
          .g = { ISL_USCALED, 8 },
          .b = { ISL_USCALED, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R64G64B64A64_FLOAT] = {
      ISL_FORMAT_R64G64B64A64_FLOAT,
      .bs = 32,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 64 },
          .g = { ISL_SFLOAT, 64 },
          .b = { ISL_SFLOAT, 64 },
          .a = { ISL_SFLOAT, 64 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R64G64B64_FLOAT] = {
      ISL_FORMAT_R64G64B64_FLOAT,
      .bs = 24,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 64 },
          .g = { ISL_SFLOAT, 64 },
          .b = { ISL_SFLOAT, 64 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_BC4_SNORM] = {
      ISL_FORMAT_BC4_SNORM,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_RGTC1,
   },

   [ISL_FORMAT_BC5_SNORM] = {
      ISL_FORMAT_BC5_SNORM,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 8 },
          .g = { ISL_SNORM, 8 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_RGTC2,
   },

   [ISL_FORMAT_R16G16B16_FLOAT] = {
      ISL_FORMAT_R16G16B16_FLOAT,
      .bs = 6,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 16 },
          .g = { ISL_SFLOAT, 16 },
          .b = { ISL_SFLOAT, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16_UNORM] = {
      ISL_FORMAT_R16G16B16_UNORM,
      .bs = 6,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 16 },
          .g = { ISL_UNORM, 16 },
          .b = { ISL_UNORM, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16_SNORM] = {
      ISL_FORMAT_R16G16B16_SNORM,
      .bs = 6,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 16 },
          .g = { ISL_SNORM, 16 },
          .b = { ISL_SNORM, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16_SSCALED] = {
      ISL_FORMAT_R16G16B16_SSCALED,
      .bs = 6,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 16 },
          .g = { ISL_SSCALED, 16 },
          .b = { ISL_SSCALED, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16_USCALED] = {
      ISL_FORMAT_R16G16B16_USCALED,
      .bs = 6,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 16 },
          .g = { ISL_USCALED, 16 },
          .b = { ISL_USCALED, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_BC6H_SF16] = {
      ISL_FORMAT_BC6H_SF16,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_SFLOAT, 16 },
          .g = { ISL_SFLOAT, 16 },
          .b = { ISL_SFLOAT, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_BPTC,
   },

   [ISL_FORMAT_BC7_UNORM] = {
      ISL_FORMAT_BC7_UNORM,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_BPTC,
   },

   [ISL_FORMAT_BC7_UNORM_SRGB] = {
      ISL_FORMAT_BC7_UNORM_SRGB,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_BPTC,
   },

   [ISL_FORMAT_BC6H_UF16] = {
      ISL_FORMAT_BC6H_UF16,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UFLOAT, 16 },
          .g = { ISL_UFLOAT, 16 },
          .b = { ISL_UFLOAT, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_BPTC,
   },

   [ISL_FORMAT_PLANAR_420_8] = {
      ISL_FORMAT_PLANAR_420_8,
      .bs = 0,
      .bw = 0, .bh = 0, .bd = 0,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_YUV,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8_UNORM_SRGB] = {
      ISL_FORMAT_R8G8B8_UNORM_SRGB,
      .bs = 3,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_ETC1_RGB8] = {
      ISL_FORMAT_ETC1_RGB8,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_ETC1,
   },

   [ISL_FORMAT_ETC2_RGB8] = {
      ISL_FORMAT_ETC2_RGB8,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_EAC_R11] = {
      ISL_FORMAT_EAC_R11,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 11 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_EAC_RG11] = {
      ISL_FORMAT_EAC_RG11,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 11 },
          .g = { ISL_UNORM, 11 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_EAC_SIGNED_R11] = {
      ISL_FORMAT_EAC_SIGNED_R11,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 11 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_EAC_SIGNED_RG11] = {
      ISL_FORMAT_EAC_SIGNED_RG11,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 11 },
          .g = { ISL_SNORM, 11 },
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_ETC2_SRGB8] = {
      ISL_FORMAT_ETC2_SRGB8,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_R16G16B16_UINT] = {
      ISL_FORMAT_R16G16B16_UINT,
      .bs = 6,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 16 },
          .g = { ISL_UINT, 16 },
          .b = { ISL_UINT, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R16G16B16_SINT] = {
      ISL_FORMAT_R16G16B16_SINT,
      .bs = 6,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 16 },
          .g = { ISL_SINT, 16 },
          .b = { ISL_SINT, 16 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R32_SFIXED] = {
      ISL_FORMAT_R32_SFIXED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SFIXED, 16 },
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10A2_SNORM] = {
      ISL_FORMAT_R10G10B10A2_SNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 10 },
          .g = { ISL_SNORM, 10 },
          .b = { ISL_SNORM, 10 },
          .a = { ISL_SNORM, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10A2_USCALED] = {
      ISL_FORMAT_R10G10B10A2_USCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 10 },
          .g = { ISL_USCALED, 10 },
          .b = { ISL_USCALED, 10 },
          .a = { ISL_USCALED, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10A2_SSCALED] = {
      ISL_FORMAT_R10G10B10A2_SSCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 10 },
          .g = { ISL_SSCALED, 10 },
          .b = { ISL_SSCALED, 10 },
          .a = { ISL_SSCALED, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R10G10B10A2_SINT] = {
      ISL_FORMAT_R10G10B10A2_SINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 10 },
          .g = { ISL_SINT, 10 },
          .b = { ISL_SINT, 10 },
          .a = { ISL_SINT, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B10G10R10A2_SNORM] = {
      ISL_FORMAT_B10G10R10A2_SNORM,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SNORM, 10 },
          .g = { ISL_SNORM, 10 },
          .b = { ISL_SNORM, 10 },
          .a = { ISL_SNORM, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B10G10R10A2_USCALED] = {
      ISL_FORMAT_B10G10R10A2_USCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_USCALED, 10 },
          .g = { ISL_USCALED, 10 },
          .b = { ISL_USCALED, 10 },
          .a = { ISL_USCALED, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B10G10R10A2_SSCALED] = {
      ISL_FORMAT_B10G10R10A2_SSCALED,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SSCALED, 10 },
          .g = { ISL_SSCALED, 10 },
          .b = { ISL_SSCALED, 10 },
          .a = { ISL_SSCALED, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B10G10R10A2_UINT] = {
      ISL_FORMAT_B10G10R10A2_UINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 10 },
          .g = { ISL_UINT, 10 },
          .b = { ISL_UINT, 10 },
          .a = { ISL_UINT, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_B10G10R10A2_SINT] = {
      ISL_FORMAT_B10G10R10A2_SINT,
      .bs = 4,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 10 },
          .g = { ISL_SINT, 10 },
          .b = { ISL_SINT, 10 },
          .a = { ISL_SINT, 2 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R64G64B64A64_PASSTHRU] = {
      ISL_FORMAT_R64G64B64A64_PASSTHRU,
      .bs = 32,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_RAW, 64 },
          .g = { ISL_RAW, 64 },
          .b = { ISL_RAW, 64 },
          .a = { ISL_RAW, 64 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R64G64B64_PASSTHRU] = {
      ISL_FORMAT_R64G64B64_PASSTHRU,
      .bs = 24,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_RAW, 64 },
          .g = { ISL_RAW, 64 },
          .b = { ISL_RAW, 64 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_ETC2_RGB8_PTA] = {
      ISL_FORMAT_ETC2_RGB8_PTA,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 1 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_ETC2_SRGB8_PTA] = {
      ISL_FORMAT_ETC2_SRGB8_PTA,
      .bs = 8,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 1 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_ETC2_EAC_RGBA8] = {
      ISL_FORMAT_ETC2_EAC_RGBA8,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_ETC2_EAC_SRGB8_A8] = {
      ISL_FORMAT_ETC2_EAC_SRGB8_A8,
      .bs = 16,
      .bw = 4, .bh = 4, .bd = 1,
      .channels = {
          .r = { ISL_UNORM, 8 },
          .g = { ISL_UNORM, 8 },
          .b = { ISL_UNORM, 8 },
          .a = { ISL_UNORM, 8 },
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_SRGB,
      .txc = ISL_TXC_ETC2,
   },

   [ISL_FORMAT_R8G8B8_UINT] = {
      ISL_FORMAT_R8G8B8_UINT,
      .bs = 3,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_UINT, 8 },
          .g = { ISL_UINT, 8 },
          .b = { ISL_UINT, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_R8G8B8_SINT] = {
      ISL_FORMAT_R8G8B8_SINT,
      .bs = 3,
      .bw = 1, .bh = 1, .bd = 1,
      .channels = {
          .r = { ISL_SINT, 8 },
          .g = { ISL_SINT, 8 },
          .b = { ISL_SINT, 8 },
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_LINEAR,
      .txc = ISL_TXC_NONE,
   },

   [ISL_FORMAT_RAW] = {
      ISL_FORMAT_RAW,
      .bs = 0,
      .bw = 0, .bh = 0, .bd = 0,
      .channels = {
          .r = {},
          .g = {},
          .b = {},
          .a = {},
          .l = {},
          .i = {},
          .p = {},
      },
      .colorspace = ISL_COLORSPACE_NONE,
      .txc = ISL_TXC_NONE,
   },

};
